pub type ProxyClient = Client<HttpConnector, Incoming>;Expand description
The hyper client type used to proxy requests to backends.
Aliased Type
pub struct ProxyClient { /* private fields */ }pub type ProxyClient = Client<HttpConnector, Incoming>;The hyper client type used to proxy requests to backends.
pub struct ProxyClient { /* private fields */ }